@@ -2,6 +2,7 @@
 
 import asyncio
 import warnings
+from collections import defaultdict
 from enum import IntEnum
 from typing import List, Dict, Any, AsyncGenerator, Iterable
 
@@ -38,10 +39,20 @@ class DummySerializer:
 
 
 class MissingBehaviour(IntEnum):
+    # skip missing queue
     SKIP = 0
+    # warn that queue is missing and skip
     WARN = 1
+    # create missing queue
     CREATE = 2
+    # raise with ValueError exception
     EXCEPTION = 3
+    # wait until queue will be created by another code
+    WAIT = 4
+
+
+class DROP:
+    pass
 
 
 class AsyncLocalBroker:
@@ -58,7 +69,7 @@ class AsyncLocalBroker:
             self,
             initial_queues: Iterable[str] = tuple(),
             publish_missing: MissingBehaviour = MissingBehaviour.CREATE,
-            subscribe_missing: MissingBehaviour = MissingBehaviour.WARN,
+            subscribe_missing: MissingBehaviour = MissingBehaviour.WAIT,
             max_queue_size: int = 100
     ):
         self._queues: Dict[str, asyncio.Queue] = {}
@@ -66,6 +77,8 @@ class AsyncLocalBroker:
         self._subscribe_missing = subscribe_missing
         self._queue_size = max_queue_size
 
+        self._missing_notif: Dict[str, List[asyncio.Event]] = defaultdict(list)
+
         for q_name in initial_queues:
             self._create_queue(q_name)
 
@@ -78,10 +91,16 @@ class AsyncLocalBroker:
 
     def _create_queue(self, name):
         self._queues[name] = asyncio.Queue(maxsize=self._queue_size)
+        if name in self._missing_notif:
+            for n in self._missing_notif.pop(name):
+                n.set()
 
     def get_queue(self, name: str) -> asyncio.Queue:
         return self._queues[name]
 
+    def has_queue(self, name: str) -> bool:
+        return name in self._queues
+
     async def put(self, msg: Any, *, queue_name: str):
         if queue_name not in self._queues:
             if self._publish_missing == MissingBehaviour.SKIP:
@@ -93,11 +112,22 @@ class AsyncLocalBroker:
                 return
             elif self._publish_missing == MissingBehaviour.CREATE:
                 self._create_queue(queue_name)
+            elif self._publish_missing == MissingBehaviour.WAIT:
+                await self._missing_created(queue_name)
             else:
                 raise ValueError(f'{queue_name}: no such queue')
 
         await self._queues[queue_name].put(msg)
 
+    def _missing_created(self, queue_name):
+        event = asyncio.Event()
+        self._missing_notif[queue_name].append(event)
+
+        async def notifier():
+            await event.wait()
+            return DROP
+        return notifier()
+
     async def subscribe(self, queue_names: List[str]) -> AsyncGenerator:
 
         waiters: Dict[asyncio.Task, str] = {}
@@ -112,10 +142,12 @@ class AsyncLocalBroker:
                     return
                 elif self._subscribe_missing == MissingBehaviour.CREATE:
                     self._create_queue(queue_name)
+                elif self._subscribe_missing == MissingBehaviour.WAIT:
+                    waiters[asyncio.create_task(self._missing_created(queue_name))] = queue_name
                 else:
                     raise ValueError(f'{queue_name}: no such queue')
-
-            waiters[asyncio.create_task(self._queues[queue_name].get())] = queue_name
+            else:
+                waiters[asyncio.create_task(self._queues[queue_name].get())] = queue_name
 
         while True:
             try:
@@ -127,7 +159,9 @@ class AsyncLocalBroker:
                     # create new waiter task for this queue name
                     waiters[asyncio.create_task(self._queues[q_name].get())] = q_name
                     # yield fetched value
-                    yield fut.result()
+                    result = fut.result()
+                    if result is not DROP:
+                        yield result
                     self._queues[q_name].task_done()
             except asyncio.CancelledError:
                 for w in waiters.keys():
@@ -214,6 +248,8 @@ class AsyncLocalSubscriber(AsyncSubscriber):
 
     async def _start(self):
         self.logger.debug(f"Subscriber attached to broker {self._broker}")
+        if not self.settings.queue_names:
+            warnings.warn(f'{self.__class__.__name__}: no queues to listen on')
         self._fetcher = self._broker.subscribe(self.settings.queue_names)
 
     async def _stop(self):
