@@ -111,9 +111,36 @@ async def test_fetch_one_timeout(subscriber):
     with pytest.raises(TimeoutError):
         _payload, _meta = await subscriber._fetch_one(timeout=0.01)
 
+
 @pytest.mark.asyncio
 async def test_unstarted_subscriber(broker):
     client = AsyncLocalSubscriber(broker=broker, queue_names=['test'])
 
     with pytest.raises(RuntimeError):
         _ = await client._fetch_one()
+
+
+@pytest.mark.asyncio
+async def test_subscribe_on_missing():
+    """
+    Test if subscriber subscribed on missing queue will receive a message when queue will be created
+    :return:
+    """
+    client_1 = AsyncLocalPublisher()
+    client_2 = AsyncLocalSubscriber(queue_names=['test-missing'])
+
+    async def send():
+        task = Task()
+        task.meta.queue_name = 'test-missing'
+        await client_1._send(b'payload', task)
+
+    # create a background task to send task on missing queue (will be created)
+    asyncio.create_task(send())
+
+    async with client_2:
+        # await on subscribed queue which does not exists yet
+        assert not client_2.broker.has_queue('test-missing')
+        payload, meta = await client_2._fetch_one()
+
+    assert payload == b'payload'
+    assert meta == {}
